==> web2py_1.95.1.orig.tar.gz: web2py-1.95.1.orig/applications/admin/languages/af.py <==
# coding: utf8
{
'%Y-%m-%d': '%Y-%m-%d',
'%Y-%m-%d %H:%M:%S': '%Y-%m-%d %H:%M:%S',
'(requires internet access)': '(vereis internet toegang)',
'(something like "it-it")': '(iets soos "it-it")',
'About': 'Oor',
'About application': 'Oor program',
'Additional code for your application': 'Additionele kode vir u application',
'Admin language': 'Admin taal',
'Application name:': 'Program naam:',
'Controllers': 'Beheerders',
'Deploy on Google App Engine': 'Stuur na Google App Engine toe',
'Edit application': 'Wysig program',
'Installed applications': 'Geinstalleerde apps',
'Languages': 'Tale',
'License for': 'Lisensie vir',
'Models': 'Modelle',
'Modules': 'Modules',
'New application wizard': 'Nuwe app wizard',
'New simple application': 'Nuwe eenvoudige app',
'Plugins': 'Plugins',
'Powered by': 'Aangedryf deur',
'Searching:': 'Soek:',
'Static files': 'Static files',
'Sure you want to delete this object?': 'Is jy seker jy will hierde object verwyder?',
'The application logic, each URL path is mapped in one exposed function in the controller': 'The application logic, each URL path is mapped in one exposed function in the controller',
'The data representation, define database tables and sets': 'The data representation, define database tables and sets',
'The presentations layer, views are also known as templates': 'The presentations layer, views are also known as templates',
'There are no plugins': 'Daar is geen plugins',
'These files are served without processing, your images go here': 'Hierdie lêre is sonder veranderinge geserved, jou images gaan hier',
'To create a plugin, name a file/folder plugin_[name]': 'Om ''n plugin te skep, noem ''n lêer/gids plugin_[name]',
'Translation strings for the application': 'Vertaling woorde vir die program',
'Upload & install packed application': 'Oplaai & install gepakte program',
'Upload a package:': 'Oplaai ''n package:',
'Use an url:': 'Gebruik n url:',
'Views': 'Views',
'about': 'oor',
'administrative interface': 'administrative interface',
'and rename it:': 'en verander die naam:',
'change admin password': 'verander admin wagwoord',
'check for upgrades': 'soek vir upgrades',
'clean': 'maak skoon',
'collapse/expand all': 'collapse/expand all',
'compile': 'kompileer',
'controllers': 'beheerders',
'create': 'skep',
'create file with filename:': 'skep lêer met naam:',
'created by': 'geskep deur',
'crontab': 'crontab',
'currently running': 'loop tans',
'database administration': 'database administration',
'deploy': 'deploy',
'direction: ltr': 'direction: ltr',
'download layouts': 'aflaai layouts',
'download plugins': 'aflaai plugins',
'edit': 'wysig',
'errors': 'foute',
'exposes': 'exposes',
'extends': 'extends',
'files': 'lêre',
'filter': 'filter',
'help': 'hulp',
'includes': 'includes',
'install': 'installeer',
'languages': 'tale',
'loading...': 'laai...',
'logout': 'logout',
'models': 'modelle',
'modules': 'modules',
'overwrite installed app': 'skryf oor geinstalleerde program',
'pack all': 'pack alles',
'plugins': 'plugins',
'shell': 'shell',
'site': 'site',
'start wizard': 'start wizard',
'static': 'static',
'test': 'toets',
'uninstall': 'verwyder',
'update all languages': 'update all languages',
'upload': 'oplaai',
'upload file:': 'oplaai lêer:',
'upload plugin file:': 'upload plugin lêer:',
'versioning': 'versioning',
'views': 'views',
'web2py Recent Tweets': 'web2py Onlangse Tweets',
}

==> web2py_1.99.2.1.orig.tar.gz: web2py-1.99.2.1.orig/applications/admin/languages/af.py <==
# coding: utf8
{
'%Y-%m-%d': '%Y-%m-%d',
'%Y-%m-%d %H:%M:%S': '%Y-%m-%d %H:%M:%S',
'(requires internet access)': '(vereis internet toegang)',
'(something like "it-it")': '(iets soos "it-it")',
'About': 'Oor',
'About application': 'Oor program',
'Additional code for your application': 'Additionele kode vir u application',
'Admin language': 'Admin taal',
'Application name:': 'Program naam:',
'Controllers': 'Beheerders',
'Deploy on Google App Engine': 'Stuur na Google App Engine toe',
'Edit application': 'Wysig program',
'Installed applications': 'Geinstalleerde apps',
'Languages': 'Tale',
'License for': 'Lisensie vir',
'Models': 'Modelle',
'Modules': 'Modules',
'New application wizard': 'Nuwe app wizard',
'New simple application': 'Nuwe eenvoudige app',
'Plugins': 'Plugins',
'Powered by': 'Aangedryf deur',
'Searching:': 'Soek:',
'Static files': 'Static files',
'Sure you want to delete this object?': 'Is jy seker jy will hierde object verwyder?',
'The application logic, each URL path is mapped in one exposed function in the controller': 'The application logic, each URL path is mapped in one exposed function in the controller',
'The data representation, define database tables and sets': 'The data representation, define database tables and sets',
'The presentations layer, views are also known as templates': 'The presentations layer, views are also known as templates',
'There are no plugins': 'Daar is geen plugins',
'These files are served without processing, your images go here': 'Hierdie lêre is sonder veranderinge geserved, jou images gaan hier',
'To create a plugin, name a file/folder plugin_[name]': 'Om ''n plugin te skep, noem ''n lêer/gids plugin_[name]',
'Translation strings for the application': 'Vertaling woorde vir die program',
'Upload & install packed application': 'Oplaai & install gepakte program',
'Upload a package:': 'Oplaai ''n package:',
'Use an url:': 'Gebruik n url:',
'Views': 'Views',
'About': 'oor',
'administrative interface': 'administrative interface',
'and rename it:': 'en verander die naam:',
'Change admin password': 'verander admin wagwoord',
'Check for upgrades': 'soek vir upgrades',
'Clean': 'maak skoon',
'collapse/expand all': 'collapse/expand all',
'Compile': 'kompileer',
'controllers': 'beheerders',
'Create': 'skep',
'create file with filename:': 'skep lêer met naam:',
'created by': 'geskep deur',
'crontab': 'crontab',
'currently running': 'loop tans',
'database administration': 'database administration',
'Deploy': 'deploy',
'direction: ltr': 'direction: ltr',
'download layouts': 'aflaai layouts',
'download plugins': 'aflaai plugins',
'Edit': 'wysig',
'Errors': 'foute',
'exposes': 'exposes',
'extends': 'extends',
'files': 'lêre',
'filter': 'filter',
'Help': 'hulp',
'includes': 'includes',
'Install': 'installeer',
'languages': 'tale',
'loading...': 'laai...',
'Logout': 'logout',
'models': 'modelle',
'modules': 'modules',
'Overwrite installed app': 'skryf oor geinstalleerde program',
'Pack all': 'pack alles',
'plugins': 'plugins',
'shell': 'shell',
'Site': 'site',
'Start wizard': 'start wizard',
'static': 'static',
'test': 'toets',
'Uninstall': 'verwyder',
'update all languages': 'update all languages',
'upload': 'oplaai',
'upload file:': 'oplaai lêer:',
'upload plugin file:': 'upload plugin lêer:',
'versioning': 'versioning',
'views': 'views',
'web2py Recent Tweets': 'web2py Onlangse Tweets',
}
